Quickly view NBA player stats in the terminal using data retrieved from basketball-reference.

Supports viewing averages, totals, and advanced statistics for regular season and playoffs.

![NBA stats demo](assets/nba-stats-demo.gif)
